==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/vai-Latn-LR.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "y MMMM",
    yMMMd => "MMM d y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "vai-Latn-LR",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "t\N{U+025b}\N{U+025b}n\N{U+025b}\N{U+025b}",
    "talata",
    "alaba",
    "aimisa",
    "aijima",
    "si\N{U+0253}iti",
    "lahadi"
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S"
  ],
  day_format_wide => [
    "t\N{U+025b}\N{U+025b}n\N{U+025b}\N{U+025b}",
    "talata",
    "alaba",
    "aimisa",
    "aijima",
    "si\N{U+0253}iti",
    "lahadi"
  ],
  day_stand_alone_abbreviated => [
    "t\N{U+025b}\N{U+025b}n\N{U+025b}\N{U+025b}",
    "talata",
    "alaba",
    "aimisa",
    "aijima",
    "si\N{U+0253}iti",
    "lahadi"
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S"
  ],
  day_stand_alone_wide => [
    "t\N{U+025b}\N{U+025b}n\N{U+025b}\N{U+025b}",
    "talata",
    "alaba",
    "aimisa",
    "aijima",
    "si\N{U+0253}iti",
    "lahadi"
  ],
  era_abbreviated => [
    "BCE",
    "CE"
  ],
  era_narrow => [
    "BCE",
    "CE"
  ],
  era_wide => [
    "BCE",
    "CE"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Vai",
  month_format_abbreviated => [
    "luukao kem\N{U+00e3}",
    "\N{U+0253}anda\N{U+0253}u",
    "v\N{U+0254}\N{U+0254}",
    "fulu",
    "goo",
    6,
    7,
    "k\N{U+0254}nde",
    "saah",
    "galo",
    "kenpkato \N{U+0253}olol\N{U+0254}",
    "luukao l\N{U+0254}ma"
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_format_wide => [
    "luukao kem\N{U+00e3}",
    "\N{U+0253}anda\N{U+0253}u",
    "v\N{U+0254}\N{U+0254}",
    "fulu",
    "goo",
    6,
    7,
    "k\N{U+0254}nde",
    "saah",
    "galo",
    "kenpkato \N{U+0253}olol\N{U+0254}",
    "luukao l\N{U+0254}ma"
  ],
  month_stand_alone_abbreviated => [
    "luukao kem\N{U+00e3}",
    "\N{U+0253}anda\N{U+0253}u",
    "v\N{U+0254}\N{U+0254}",
    "fulu",
    "goo",
    6,
    7,
    "k\N{U+0254}nde",
    "saah",
    "galo",
    "kenpkato \N{U+0253}olol\N{U+0254}",
    "luukao l\N{U+0254}ma"
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_stand_alone_wide => [
    "luukao kem\N{U+00e3}",
    "\N{U+0253}anda\N{U+0253}u",
    "v\N{U+0254}\N{U+0254}",
    "fulu",
    "goo",
    6,
    7,
    "k\N{U+0254}nde",
    "saah",
    "galo",
    "kenpkato \N{U+0253}olol\N{U+0254}",
    "luukao l\N{U+0254}ma"
  ],
  name => "Vai Liberia Latin",
  native_language => "Vai",
  native_name => "Vai Laibhiya Latn",
  native_script => "Latn",
  native_territory => "Laibhiya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  script => "Latin",
  territory => "Liberia",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.25.tar.gz: DateTime-Locale-1.25/share/vai-Latn-LR.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "y MMMM",
    yMMMd => "MMM d y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "vai-Latn-LR",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "t\N{U+025b}\N{U+025b}n\N{U+025b}\N{U+025b}",
    "talata",
    "alaba",
    "aimisa",
    "aijima",
    "si\N{U+0253}iti",
    "lahadi",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "t\N{U+025b}\N{U+025b}n\N{U+025b}\N{U+025b}",
    "talata",
    "alaba",
    "aimisa",
    "aijima",
    "si\N{U+0253}iti",
    "lahadi",
  ],
  day_stand_alone_abbreviated => [
    "t\N{U+025b}\N{U+025b}n\N{U+025b}\N{U+025b}",
    "talata",
    "alaba",
    "aimisa",
    "aijima",
    "si\N{U+0253}iti",
    "lahadi",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "t\N{U+025b}\N{U+025b}n\N{U+025b}\N{U+025b}",
    "talata",
    "alaba",
    "aimisa",
    "aijima",
    "si\N{U+0253}iti",
    "lahadi",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Vai",
  month_format_abbreviated => [
    "luukao kem\N{U+00e3}",
    "\N{U+0253}anda\N{U+0253}u",
    "v\N{U+0254}\N{U+0254}",
    "fulu",
    "goo",
    6,
    7,
    "k\N{U+0254}nde",
    "saah",
    "galo",
    "kenpkato \N{U+0253}olol\N{U+0254}",
    "luukao l\N{U+0254}ma",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "luukao kem\N{U+00e3}",
    "\N{U+0253}anda\N{U+0253}u",
    "v\N{U+0254}\N{U+0254}",
    "fulu",
    "goo",
    6,
    7,
    "k\N{U+0254}nde",
    "saah",
    "galo",
    "kenpkato \N{U+0253}olol\N{U+0254}",
    "luukao l\N{U+0254}ma",
  ],
  month_stand_alone_abbreviated => [
    "luukao kem\N{U+00e3}",
    "\N{U+0253}anda\N{U+0253}u",
    "v\N{U+0254}\N{U+0254}",
    "fulu",
    "goo",
    6,
    7,
    "k\N{U+0254}nde",
    "saah",
    "galo",
    "kenpkato \N{U+0253}olol\N{U+0254}",
    "luukao l\N{U+0254}ma",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "luukao kem\N{U+00e3}",
    "\N{U+0253}anda\N{U+0253}u",
    "v\N{U+0254}\N{U+0254}",
    "fulu",
    "goo",
    6,
    7,
    "k\N{U+0254}nde",
    "saah",
    "galo",
    "kenpkato \N{U+0253}olol\N{U+0254}",
    "luukao l\N{U+0254}ma",
  ],
  name => "Vai Liberia Latin",
  native_language => "Vai",
  native_name => "Vai Laibhiya Latn",
  native_script => "Latn",
  native_territory => "Laibhiya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => "Latin",
  territory => "Liberia",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 36,
}
